searchData={"items":[{"type":"module","title":"MplBubblegum","doc":"A comprehensive Elixir library for working with compressed NFTs (cNFTs) on Solana.","ref":"MplBubblegum.html"},{"type":"module","title":"Overview - MplBubblegum","doc":"MplBubblegum provides tools to create, mint, and transfer compressed NFTs on Solana\nusing the Metaplex Bubblegum protocol. Compressed NFTs offer significant cost savings\nover traditional NFTs by leveraging Solana's state compression feature.","ref":"MplBubblegum.html#module-overview"},{"type":"module","title":"Installation - MplBubblegum","doc":"Add `mpl_bubblegum_lib` to your mix.exs dependencies:\n\n```elixir\ndef deps do\n  [\n    {:mpl_bubblegum_lib, \"~> 0.1.0\"}\n  ]\nend\n```\n\nPublished on Hex.pm: [https://hex.pm/packages/mpl_bubblegum_nifs](https://hex.pm/packages/mpl_bubblegum_nifs)","ref":"MplBubblegum.html#module-installation"},{"type":"module","title":"Requirements - MplBubblegum","doc":"* Elixir 1.14 or later\n* Erlang/OTP 25 or later\n* A Helius RPC URL (standard Solana RPC does not support DAS API)","ref":"MplBubblegum.html#module-requirements"},{"type":"module","title":"Getting Started - MplBubblegum","doc":"The typical workflow for using compressed NFTs is:\n\n1. **Setup Connection** - Initialize a connection with your wallet and RPC URL\n2. **Create Merkle Tree** - Create an on-chain Merkle tree to store your NFTs\n3. **Mint NFTs** - Mint compressed NFTs into your Merkle tree\n4. **Transfer NFTs** - Transfer NFTs to other wallets as needed","ref":"MplBubblegum.html#module-getting-started"},{"type":"module","title":"Example Usage - MplBubblegum","doc":"```elixir\n# 1. Set up connection\nsecret_key = \"your_wallet_private_key\"\nrpc_url = \"https://your-helius-rpc-endpoint.helius.xyz/...\"\nMplBubblegum.create_connection(secret_key, rpc_url)\n\n# 2. Create a Merkle tree\nmerkle_tree = MplBubblegum.create_tree_config()\n\n# 3. Mint a compressed NFT\nname = \"My Awesome NFT\"\nsymbol = \"MANFT\"\nuri = \"https://arweave.net/your-metadata-json-uri\"\ncreator = \"your_wallet_address\"\nroyalty_share = \"100\"  # 100% royalty to creator\n\nsignature = MplBubblegum.mint_v1(merkle_tree, name, symbol, uri, creator, royalty_share)\n\n# 4. Transfer an NFT to another wallet\nrecipient = \"recipient_wallet_address\"\nasset_id = \"compressed_nft_asset_id\"\n\nsignature = MplBubblegum.transfer(asset_id, recipient)\n```","ref":"MplBubblegum.html#module-example-usage"},{"type":"module","title":"Module Structure - MplBubblegum","doc":"This library is organized into several modules:\n\n* `MplBubblegum` - Main module with re-exported functions for simplicity\n* `MplBubblegum.Connection` - Connection management\n* `MplBubblegum.Tree` - Merkle tree creation and management\n* `MplBubblegum.Mint` - Functionality for minting compressed NFTs\n* `MplBubblegum.Transfer` - Functionality for transferring compressed NFTs\n* `MplBubblegum.RPC` - Low-level RPC communication with Solana","ref":"MplBubblegum.html#module-module-structure"},{"type":"module","title":"Native Implementation - MplBubblegum","doc":"The core functionality is implemented in Rust using Rustler NIFs,\nwhich provide high performance and direct access to Solana's cryptographic\nprimitives and transaction building logic.","ref":"MplBubblegum.html#module-native-implementation"},{"type":"function","title":"MplBubblegum.create_connection/2","doc":"Creates a new connection with the given secret key and RPC URL.\n\nSee `MplBubblegum.Connection.create_connection/2` for details.","ref":"MplBubblegum.html#create_connection/2"},{"type":"function","title":"MplBubblegum.create_tree_config/0","doc":"Creates a new Merkle tree configuration.\n\nSee `MplBubblegum.Tree.create_tree_config/0` for details.","ref":"MplBubblegum.html#create_tree_config/0"},{"type":"function","title":"MplBubblegum.create_tree_config_builder/1","doc":"Creates a Merkle tree configuration transaction.\n\nThis is a low-level NIF function that builds a transaction for creating\na Merkle tree. Most users should use `create_tree_config/0` instead.","ref":"MplBubblegum.html#create_tree_config_builder/1"},{"type":"function","title":"Parameters - MplBubblegum.create_tree_config_builder/1","doc":"* `secret_key` - Your wallet's secret key","ref":"MplBubblegum.html#create_tree_config_builder/1-parameters"},{"type":"function","title":"Returns - MplBubblegum.create_tree_config_builder/1","doc":"* `[serialized_transaction, merkle_tree_address]` - A list containing the\n  serialized transaction and the new Merkle tree address","ref":"MplBubblegum.html#create_tree_config_builder/1-returns"},{"type":"function","title":"Error Handling - MplBubblegum.create_tree_config_builder/1","doc":"Will raise a NIF-specific error if:\n* The NIF library fails to load\n* The secret key is invalid\n* Transaction creation fails","ref":"MplBubblegum.html#create_tree_config_builder/1-error-handling"},{"type":"function","title":"MplBubblegum.mint_v1/6","doc":"Mints a new compressed NFT.\n\nSee `MplBubblegum.Mint.mint_v1/6` for details.","ref":"MplBubblegum.html#mint_v1/6"},{"type":"function","title":"MplBubblegum.mint_v1_builder/7","doc":"Creates a mint transaction for a compressed NFT.\n\nThis is a low-level NIF function that builds a transaction for minting\na compressed NFT. Most users should use `mint_v1/6` instead.","ref":"MplBubblegum.html#mint_v1_builder/7"},{"type":"function","title":"Parameters - MplBubblegum.mint_v1_builder/7","doc":"* `secret_key` - Your wallet's secret key\n* `merkle_tree` - Address of the Merkle tree\n* `name` - Name of the NFT\n* `symbol` - Symbol/ticker of the NFT collection\n* `uri` - URI pointing to the NFT's metadata JSON\n* `basis` - Creator's wallet address\n* `share` - Creator's royalty share as a string (e.g., \"100\" for 100%)","ref":"MplBubblegum.html#mint_v1_builder/7-parameters"},{"type":"function","title":"Returns - MplBubblegum.mint_v1_builder/7","doc":"* `binary()` - The serialized transaction","ref":"MplBubblegum.html#mint_v1_builder/7-returns"},{"type":"function","title":"Error Handling - MplBubblegum.mint_v1_builder/7","doc":"Will raise a NIF-specific error if:\n* The NIF library fails to load\n* Any parameter is invalid\n* Transaction creation fails","ref":"MplBubblegum.html#mint_v1_builder/7-error-handling"},{"type":"function","title":"MplBubblegum.send_transaction/1","doc":"Sends a transaction to the Solana network.\n\nSee `MplBubblegum.RPC.send_transaction/1` for details.","ref":"MplBubblegum.html#send_transaction/1"},{"type":"function","title":"MplBubblegum.transfer/2","doc":"Transfers a compressed NFT to a new owner.\n\nSee `MplBubblegum.Transfer.transfer/2` for details.","ref":"MplBubblegum.html#transfer/2"},{"type":"function","title":"MplBubblegum.transfer_builder/9","doc":"Creates a transfer transaction for a compressed NFT.\n\nThis is a low-level NIF function that builds a transaction for transferring\na compressed NFT. Most users should use `transfer/2` instead.","ref":"MplBubblegum.html#transfer_builder/9"},{"type":"function","title":"Parameters - MplBubblegum.transfer_builder/9","doc":"* `payer_secret_key` - Your wallet's secret key\n* `to_address` - Recipient's wallet address\n* `asset_id` - Asset ID of the compressed NFT\n* `nonce` - Leaf ID in the Merkle tree\n* `data_hash` - Hash of the NFT data\n* `creator_hash` - Hash of the NFT creators\n* `root` - Current root hash of the Merkle tree\n* `proof` - Merkle proof for the NFT\n* `merkle_tree` - Address of the Merkle tree","ref":"MplBubblegum.html#transfer_builder/9-parameters"},{"type":"function","title":"Returns - MplBubblegum.transfer_builder/9","doc":"* `binary()` - The serialized transaction","ref":"MplBubblegum.html#transfer_builder/9-returns"},{"type":"function","title":"Error Handling - MplBubblegum.transfer_builder/9","doc":"Will raise a NIF-specific error if:\n* The NIF library fails to load\n* Any parameter is invalid\n* Transaction creation fails","ref":"MplBubblegum.html#transfer_builder/9-error-handling"},{"type":"module","title":"MplBubblegum.Connection","doc":"Manages the connection to Solana RPC for Bubblegum NFT interactions.","ref":"MplBubblegum.Connection.html"},{"type":"module","title":"Connection Setup - MplBubblegum.Connection","doc":"Before using any functionality in the MplBubblegum library, you must establish\na connection to a Solana RPC endpoint using `create_connection/2`.","ref":"MplBubblegum.Connection.html#module-connection-setup"},{"type":"module","title":"Helius RPC Requirement - MplBubblegum.Connection","doc":"**IMPORTANT:** You must use a Helius RPC URL (https://helius.xyz) as your RPC endpoint.\nStandard Solana RPC nodes do not support the Digital Asset Standard (DAS) API,\nwhich is required for compressed NFT operations.","ref":"MplBubblegum.Connection.html#module-helius-rpc-requirement"},{"type":"module","title":"Example Usage - MplBubblegum.Connection","doc":"```elixir\n# Initialize the connection\nsecret_key = \"your_wallet_private_key\"\nrpc_url = \"https://your-helius-rpc-endpoint.helius.xyz/...\"\n\nMplBubblegum.Connection.create_connection(secret_key, rpc_url)\n\n# Now you can use other MplBubblegum functions\n```","ref":"MplBubblegum.Connection.html#module-example-usage"},{"type":"function","title":"MplBubblegum.Connection.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"MplBubblegum.Connection.html#child_spec/1"},{"type":"function","title":"MplBubblegum.Connection.create_connection/2","doc":"Creates a new connection with the given secret key and RPC URL.","ref":"MplBubblegum.Connection.html#create_connection/2"},{"type":"function","title":"Parameters - MplBubblegum.Connection.create_connection/2","doc":"* `secret_key` - The private key of your Solana wallet as a binary string\n* `rpc_url` - The Helius RPC endpoint URL as a binary string","ref":"MplBubblegum.Connection.html#create_connection/2-parameters"},{"type":"function","title":"Returns - MplBubblegum.Connection.create_connection/2","doc":"* `{:ok, pid}` - If the connection was successfully created\n* `{:error, reason}` - If the connection could not be established","ref":"MplBubblegum.Connection.html#create_connection/2-returns"},{"type":"function","title":"Examples - MplBubblegum.Connection.create_connection/2","doc":"```elixir\nMplBubblegum.Connection.create_connection(\n  \"your_wallet_private_key\",\n  \"https://your-helius-rpc-endpoint.helius.xyz/...\"\n)\n```","ref":"MplBubblegum.Connection.html#create_connection/2-examples"},{"type":"function","title":"Error Handling - MplBubblegum.Connection.create_connection/2","doc":"Will raise an `ArgumentError` if the connection has already been established.\nIf you need to change the connection details, restart your application.","ref":"MplBubblegum.Connection.html#create_connection/2-error-handling"},{"type":"function","title":"MplBubblegum.Connection.get_rpc_url/0","doc":"Returns the stored RPC URL.","ref":"MplBubblegum.Connection.html#get_rpc_url/0"},{"type":"function","title":"Returns - MplBubblegum.Connection.get_rpc_url/0","doc":"* `binary()` - The RPC URL provided during connection setup","ref":"MplBubblegum.Connection.html#get_rpc_url/0-returns"},{"type":"function","title":"Error Handling - MplBubblegum.Connection.get_rpc_url/0","doc":"Will raise a `RuntimeError` if called before establishing a connection\nwith `create_connection/2`.","ref":"MplBubblegum.Connection.html#get_rpc_url/0-error-handling"},{"type":"function","title":"Examples - MplBubblegum.Connection.get_rpc_url/0","doc":"```elixir\nrpc_url = MplBubblegum.Connection.get_rpc_url()\n```","ref":"MplBubblegum.Connection.html#get_rpc_url/0-examples"},{"type":"function","title":"MplBubblegum.Connection.get_secret_key/0","doc":"Returns the stored secret key.","ref":"MplBubblegum.Connection.html#get_secret_key/0"},{"type":"function","title":"Returns - MplBubblegum.Connection.get_secret_key/0","doc":"* `binary()` - The secret key provided during connection setup","ref":"MplBubblegum.Connection.html#get_secret_key/0-returns"},{"type":"function","title":"Error Handling - MplBubblegum.Connection.get_secret_key/0","doc":"Will raise a `RuntimeError` if called before establishing a connection\nwith `create_connection/2`.","ref":"MplBubblegum.Connection.html#get_secret_key/0-error-handling"},{"type":"function","title":"Examples - MplBubblegum.Connection.get_secret_key/0","doc":"```elixir\nsecret_key = MplBubblegum.Connection.get_secret_key()\n```","ref":"MplBubblegum.Connection.html#get_secret_key/0-examples"},{"type":"module","title":"MplBubblegum.Mint","doc":"Functions for minting compressed NFTs on Solana.","ref":"MplBubblegum.Mint.html"},{"type":"module","title":"Overview - MplBubblegum.Mint","doc":"Compressed NFTs (cNFTs) use Solana's state compression feature to store NFT data\noff-chain while maintaining the security guarantees of the blockchain. This results\nin significantly lower costs compared to traditional NFTs.","ref":"MplBubblegum.Mint.html#module-overview"},{"type":"module","title":"Requirements - MplBubblegum.Mint","doc":"Before minting, ensure you have:\n\n1. Established a connection using `MplBubblegum.Connection.create_connection/2`\n2. Created a Merkle tree account to store your compressed NFTs\n3. Sufficient SOL in your wallet to cover transaction fees","ref":"MplBubblegum.Mint.html#module-requirements"},{"type":"module","title":"Example Usage - MplBubblegum.Mint","doc":"```elixir\n# First establish a connection\nMplBubblegum.Connection.create_connection(secret_key, rpc_url)\n\n# Then mint a compressed NFT\nsignature = MplBubblegum.Mint.mint_v1(\n  \"merkle_tree_address\",\n  \"My NFT\",\n  \"MNFT\",\n  \"https://arweave.net/my-metadata-uri\",\n  \"creator_address\",\n  \"100\"  # 100% royalty to the creator\n)\n```","ref":"MplBubblegum.Mint.html#module-example-usage"},{"type":"function","title":"MplBubblegum.Mint.mint_v1/6","doc":"Mints a new compressed NFT and returns the transaction signature.","ref":"MplBubblegum.Mint.html#mint_v1/6"},{"type":"function","title":"Parameters - MplBubblegum.Mint.mint_v1/6","doc":"* `merkle_tree` - The address of the Merkle tree account as a base58 string\n* `name` - The name of the NFT\n* `symbol` - The symbol/ticker of the NFT collection\n* `uri` - The URI pointing to the NFT's metadata JSON file (typically on Arweave)\n* `basis` - The creator's wallet address as a base58 string\n* `share` - The creator's royalty share as a string (e.g., \"100\" for 100%)","ref":"MplBubblegum.Mint.html#mint_v1/6-parameters"},{"type":"function","title":"Returns - MplBubblegum.Mint.mint_v1/6","doc":"* `binary()` - The transaction signature as a base58 string","ref":"MplBubblegum.Mint.html#mint_v1/6-returns"},{"type":"function","title":"Error Handling - MplBubblegum.Mint.mint_v1/6","doc":"May raise errors in the following cases:\n\n* Connection not established\n* Invalid Merkle tree address\n* Transaction failure\n* Network issues","ref":"MplBubblegum.Mint.html#mint_v1/6-error-handling"},{"type":"function","title":"Examples - MplBubblegum.Mint.mint_v1/6","doc":"```elixir\nsignature = MplBubblegum.Mint.mint_v1(\n  \"9WzDXyMrFftHVK4jBUEcqABUVVjLPCT9keST9ycxL22F\",  # Merkle tree address\n  \"Awesome NFT\",                                    # NFT name\n  \"ANFT\",                                           # Symbol\n  \"https://arweave.net/abc123\",                     # Metadata URI\n  \"DEF456GHI789jklMNOpqrSTUvwxYZ\",                  # Creator address\n  \"100\"                                             # 100% royalty\n)\n```","ref":"MplBubblegum.Mint.html#mint_v1/6-examples"},{"type":"module","title":"MplBubblegum.RPC","doc":"Handles RPC communication with the Solana blockchain for compressed NFT operations.","ref":"MplBubblegum.RPC.html"},{"type":"module","title":"Overview - MplBubblegum.RPC","doc":"This module provides functions to interact with the Solana blockchain through\nRPC API calls, specifically for compressed NFT (cNFT) operations using the\nDigital Asset Standard (DAS) API.","ref":"MplBubblegum.RPC.html#module-overview"},{"type":"module","title":"Requirements - MplBubblegum.RPC","doc":"* A connection must be established with `MplBubblegum.Connection.create_connection/2`\n* A Helius RPC URL is required as the standard Solana RPC endpoints don't support DAS API","ref":"MplBubblegum.RPC.html#module-requirements"},{"type":"module","title":"API Methods - MplBubblegum.RPC","doc":"The module supports the following Solana RPC methods:\n\n* `sendTransaction` - Submit a signed transaction to the Solana network\n* `getAssetBatch` - Retrieve metadata for compressed NFTs (DAS API)\n* `getAssetProofBatch` - Retrieve merkle proofs for compressed NFTs (DAS API)","ref":"MplBubblegum.RPC.html#module-api-methods"},{"type":"function","title":"MplBubblegum.RPC.get_asset_data/1","doc":"Gets asset data for a compressed NFT using the Digital Asset Standard (DAS) API.","ref":"MplBubblegum.RPC.html#get_asset_data/1"},{"type":"function","title":"Parameters - MplBubblegum.RPC.get_asset_data/1","doc":"* `asset_id` - The asset ID of the compressed NFT","ref":"MplBubblegum.RPC.html#get_asset_data/1-parameters"},{"type":"function","title":"Returns - MplBubblegum.RPC.get_asset_data/1","doc":"* `{:ok, asset_data}` - The asset data as a map on success\n* `{:error, reason}` - Error information on failure","ref":"MplBubblegum.RPC.html#get_asset_data/1-returns"},{"type":"function","title":"Examples - MplBubblegum.RPC.get_asset_data/1","doc":"```elixir\ncase MplBubblegum.RPC.get_asset_data(\"4mKSoDDqApmF1DqXvVTSL7sGe1pCP2q6KomxEsYQMgZX\") do\n  {:ok, asset_data} ->\n    # Process the asset data\n\n  {:error, reason} ->\n    # Handle the error\nend\n```","ref":"MplBubblegum.RPC.html#get_asset_data/1-examples"},{"type":"function","title":"MplBubblegum.RPC.get_asset_proof/1","doc":"Gets asset proof for a compressed NFT using the Digital Asset Standard (DAS) API.\n\nThe proof is used to verify the authenticity and ownership of compressed NFTs\nstored in a merkle tree.","ref":"MplBubblegum.RPC.html#get_asset_proof/1"},{"type":"function","title":"Parameters - MplBubblegum.RPC.get_asset_proof/1","doc":"* `asset_id` - The asset ID of the compressed NFT","ref":"MplBubblegum.RPC.html#get_asset_proof/1-parameters"},{"type":"function","title":"Returns - MplBubblegum.RPC.get_asset_proof/1","doc":"* `{:ok, proof_data}` - The asset proof as a map on success\n* `{:error, reason}` - Error information on failure","ref":"MplBubblegum.RPC.html#get_asset_proof/1-returns"},{"type":"function","title":"Examples - MplBubblegum.RPC.get_asset_proof/1","doc":"```elixir\ncase MplBubblegum.RPC.get_asset_proof(\"4mKSoDDqApmF1DqXvVTSL7sGe1pCP2q6KomxEsYQMgZX\") do\n  {:ok, proof_data} ->\n    # Process the proof data\n\n  {:error, reason} ->\n    # Handle the error\nend\n```","ref":"MplBubblegum.RPC.html#get_asset_proof/1-examples"},{"type":"function","title":"MplBubblegum.RPC.send_transaction/1","doc":"Sends a signed transaction to the Solana network.","ref":"MplBubblegum.RPC.html#send_transaction/1"},{"type":"function","title":"Parameters - MplBubblegum.RPC.send_transaction/1","doc":"* `tx_hash` - The base64-encoded transaction as a string","ref":"MplBubblegum.RPC.html#send_transaction/1-parameters"},{"type":"function","title":"Returns - MplBubblegum.RPC.send_transaction/1","doc":"* `{:ok, signature}` - On successful transaction submission, returns the transaction signature\n* `{:error, reason}` - On failure, returns the error reason","ref":"MplBubblegum.RPC.html#send_transaction/1-returns"},{"type":"function","title":"Error Handling - MplBubblegum.RPC.send_transaction/1","doc":"Common error cases include:\n\n* Connection not established\n* Invalid RPC URL\n* Network connectivity issues\n* Invalid transaction format\n* Transaction simulation failure (e.g., insufficient funds)","ref":"MplBubblegum.RPC.html#send_transaction/1-error-handling"},{"type":"function","title":"Examples - MplBubblegum.RPC.send_transaction/1","doc":"```elixir\ncase MplBubblegum.RPC.send_transaction(signed_transaction) do\n  {:ok, signature} ->\n    # Transaction submitted successfully\n    # The signature can be used to check the transaction on Solana Explorer\n\n  {:error, reason} ->\n    # Handle error case\nend\n```","ref":"MplBubblegum.RPC.html#send_transaction/1-examples"},{"type":"module","title":"MplBubblegum.Transfer","doc":"Functions for transferring compressed NFTs on Solana.","ref":"MplBubblegum.Transfer.html"},{"type":"module","title":"Overview - MplBubblegum.Transfer","doc":"This module provides functionality to transfer ownership of compressed NFTs (cNFTs)\nthat were created using the Metaplex Bubblegum standard. Compressed NFTs use Solana's\nstate compression feature which allows for much lower transaction costs compared to\ntraditional NFTs.","ref":"MplBubblegum.Transfer.html#module-overview"},{"type":"module","title":"Prerequisites - MplBubblegum.Transfer","doc":"Before transferring a compressed NFT:\n\n1. A connection must be established using `MplBubblegum.Connection.create_connection/2`\n2. You must have the asset ID of the compressed NFT you want to transfer\n3. You must own the NFT you're attempting to transfer\n4. You must have sufficient SOL in your wallet to cover transaction fees","ref":"MplBubblegum.Transfer.html#module-prerequisites"},{"type":"module","title":"Transfer Process - MplBubblegum.Transfer","doc":"The transfer process includes:\n\n1. Retrieving the current asset data and merkle proof from the blockchain\n2. Extracting compression-related data needed for the transfer\n3. Building and signing a transfer transaction\n4. Submitting the transaction to the Solana network","ref":"MplBubblegum.Transfer.html#module-transfer-process"},{"type":"module","title":"Example Usage - MplBubblegum.Transfer","doc":"```elixir\n# First establish a connection with your wallet's private key\nMplBubblegum.Connection.create_connection(secret_key, rpc_url)\n\n# Then transfer the NFT\nsignature = MplBubblegum.Transfer.transfer(\n  \"4mKSoDDqApmF1DqXvVTSL7sGe1pCP2q6KomxEsYQMgZX\",  # Asset ID\n  \"DEF456GHI789jklMNOpqrSTUvwxYZ\"                  # Recipient address\n)\n\n# The signature can be used to view the transaction on Solana Explorer\n# https://explorer.solana.com/tx/ \n```","ref":"MplBubblegum.Transfer.html#module-example-usage"},{"type":"function","title":"MplBubblegum.Transfer.transfer/2","doc":"Transfers a compressed NFT to a new owner.","ref":"MplBubblegum.Transfer.html#transfer/2"},{"type":"function","title":"Parameters - MplBubblegum.Transfer.transfer/2","doc":"* `asset_id` - The asset ID of the compressed NFT to transfer (string)\n* `to_address` - The wallet address of the recipient (string in base58 format)","ref":"MplBubblegum.Transfer.html#transfer/2-parameters"},{"type":"function","title":"Returns - MplBubblegum.Transfer.transfer/2","doc":"* `binary()` - The transaction signature as a base58 string on success","ref":"MplBubblegum.Transfer.html#transfer/2-returns"},{"type":"function","title":"Error Handling - MplBubblegum.Transfer.transfer/2","doc":"This function will raise errors in the following cases:\n\n* `RuntimeError` - If no connection has been established\n* `ArgumentError` - If the asset ID or recipient address is invalid\n* `RuntimeError` - If you don't own the NFT being transferred\n* `RuntimeError` - If the asset data or proof cannot be retrieved\n* `RuntimeError` - If the transaction fails to send","ref":"MplBubblegum.Transfer.html#transfer/2-error-handling"},{"type":"function","title":"Examples - MplBubblegum.Transfer.transfer/2","doc":"```elixir\n# Transfer an NFT to a recipient address\nsignature = MplBubblegum.Transfer.transfer(\n  \"4mKSoDDqApmF1DqXvVTSL7sGe1pCP2q6KomxEsYQMgZX\",\n  \"3Kn6a9nJLW5324a5M3qW3xTpvnwGf7nKzBmpJVLYxfEP\"\n)\n```","ref":"MplBubblegum.Transfer.html#transfer/2-examples"},{"type":"module","title":"MplBubblegum.Tree","doc":"Functions for managing Merkle tree configurations for compressed NFTs on Solana.","ref":"MplBubblegum.Tree.html"},{"type":"module","title":"Overview - MplBubblegum.Tree","doc":"This module provides functionality to create and manage Merkle trees, which are\nessential data structures for storing compressed NFTs. The Merkle tree is a\nfundamental component of Solana's state compression feature, allowing thousands\nof NFTs to be stored at a fraction of the cost of traditional NFTs.","ref":"MplBubblegum.Tree.html#module-overview"},{"type":"module","title":"Merkle Trees for Compressed NFTs - MplBubblegum.Tree","doc":"Merkle trees in Solana:\n\n* Act as on-chain storage containers for compressed NFTs\n* Allow for cryptographic verification of NFT ownership and data\n* Significantly reduce the storage costs by keeping most data off-chain\n* Require creation before minting any compressed NFTs","ref":"MplBubblegum.Tree.html#module-merkle-trees-for-compressed-nfts"},{"type":"module","title":"Prerequisites - MplBubblegum.Tree","doc":"Before creating a Merkle tree:\n\n1. A connection must be established using `MplBubblegum.Connection.create_connection/2`\n2. Your wallet must have sufficient SOL to cover the tree creation cost\n   (typically 0.01-0.05 SOL depending on tree size)","ref":"MplBubblegum.Tree.html#module-prerequisites"},{"type":"module","title":"Example Usage - MplBubblegum.Tree","doc":"```elixir\n# First establish a connection with your wallet's private key\nMplBubblegum.Connection.create_connection(secret_key, rpc_url)\n\n# Then create a new Merkle tree\nmerkle_tree_address = MplBubblegum.Tree.create_tree_config()\n\n# The returned address can now be used for minting compressed NFTs\n```","ref":"MplBubblegum.Tree.html#module-example-usage"},{"type":"function","title":"MplBubblegum.Tree.create_tree_config/0","doc":"Creates a new Merkle tree configuration for storing compressed NFTs.\n\nThis function creates an on-chain Merkle tree that can store compressed NFTs.\nThe creation process involves:\n\n1. Building a tree configuration transaction\n2. Sending the transaction to the Solana network\n3. Returning the address of the created Merkle tree","ref":"MplBubblegum.Tree.html#create_tree_config/0"},{"type":"function","title":"Returns - MplBubblegum.Tree.create_tree_config/0","doc":"* `binary()` - The Merkle tree address as a base58 string","ref":"MplBubblegum.Tree.html#create_tree_config/0-returns"},{"type":"function","title":"Error Handling - MplBubblegum.Tree.create_tree_config/0","doc":"This function will raise errors in the following cases:\n\n* `RuntimeError` - If no connection has been established\n* `RuntimeError` - If the tree creation transaction fails\n* `RuntimeError` - If there's insufficient SOL to create the tree","ref":"MplBubblegum.Tree.html#create_tree_config/0-error-handling"},{"type":"function","title":"Costs - MplBubblegum.Tree.create_tree_config/0","doc":"Creating a Merkle tree requires SOL to cover:\n\n* The rent-exempt balance for the tree account\n* Transaction fees\n\nThe exact cost depends on the tree's maximum depth and buffer size,\nwhich determines how many NFTs it can store.","ref":"MplBubblegum.Tree.html#create_tree_config/0-costs"},{"type":"function","title":"Examples - MplBubblegum.Tree.create_tree_config/0","doc":"```elixir\n# Create a new Merkle tree\nmerkle_tree_address = MplBubblegum.Tree.create_tree_config()\n\n# Use the tree address for minting compressed NFTs\nsignature = MplBubblegum.Mint.mint_v1(\n  merkle_tree_address,\n  \"My NFT\",\n  \"MNFT\",\n  \"https://arweave.net/my-metadata-uri\",\n  creator_address,\n  \"100\"\n)\n```","ref":"MplBubblegum.Tree.html#create_tree_config/0-examples"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}